************************************************************************
* File (cc-qcd_br_1413_1211.f) created on Wed Jul 16 18:26:43 MSD 2008.
************************************************************************
* This is the FORTRAN module (cc_qcd_bo_1413_1211) to calculate QCD
* integrated Born cross section for dn + up -> el + en process.
*
* It is produced by s2n package of SANC (v1.10) Project.
* Copyright (C), SANC Project Team, 2002-2008.
*
* http://sanc.jinr.ru/
* http://pcphsanc.cern.ch/
* E-mail: <sanc@jinr.ru>
************************************************************************
      subroutine cc_qcd_bo_1413_1211 (s,born)
      implicit none!
      include 's2n_declare.h'

      real*8 kappaw
      complex*16 chiws,chiwsc

      cmw2 = mw2

      kappaw = gf*rwm2/(sqrt(2d0)*4d0*pi)/alpha
      chiws = 4d0*kappaw*s/(s-cmw2)
      chiwsc = dconjg(chiws)

      born=
     & +chiws*chiwsc*pi*alpha**2*(1d0/9/s)

      born = born*conhc

      return
      end
************************************************************************
* This is the FORTRAN module (cc_qcd_br_1413_1211) to calculate QCD Born
* cross section, virtual corrections and soft gluon Bremsstrahlung
* for dn + up -> el + en process.
*
* It is produced by s2n package of SANC (v1.10) Project.
* Copyright (C), SANC Project Team, 2002-2008.
*
* http://sanc.jinr.ru/
* http://pcphsanc.cern.ch/
* E-mail: <sanc@jinr.ru>
************************************************************************
      subroutine cc_qcd_br_1413_1211 (qs,ts,us,born,soft,hard)
      implicit none!
      include 's2n_declare.h'

      real*8 costh
      real*8 ln1sdn,ln1sup
      real*8 lnlaupm,lnladnm,lnlas

      real*8 kappaw,qw
      complex*16 chiws,chiwsc

      cmw2 = mw2
      s = -qs
      t = -ts
      u = -us

      kappaw = gf*rwm2/(sqrt(2d0)*4d0*pi)/alpha
      chiws = 4d0*kappaw*s/(s-cmw2)
      chiwsc = dconjg(chiws)

      born=
     & +chiws*chiwsc*pi*alpha**2*(1d0/24/s)
     & +chiws*chiwsc*cosf*pi*alpha**2*(-1d0/12/s)
     & +chiws*chiwsc*cosf**2*pi*alpha**2*(1d0/24/s)

      born = born*conhc
      virt = 0d0
      soft = 0d0
      hard = 0d0

      if (iborn.eq.1) return

      lnlaupm = log(rupm2/tlmu2)
      lnladnm = log(rdnm2/tlmu2)
      lnlas   = log(s/tlmu2)
      ln1sdn  = log(s/mdn**2)-1d0
      ln1sup  = log(s/mup**2)-1d0

      virt=
     & +born/pi*alphas*cf*(-1+3d0/4*ln1sdn+1d0/4*ln1sdn**2+3d0/4*ln1sup+
     & 1d0/4*ln1sup**2+ddilog(1d0))
     & +lnlas*born/pi*alphas*cf*(-1d0/2*ln1sdn-1d0/2*ln1sup)

      soft=
     & +born/pi*alphas*cf*(1d0/2)
     & +ln1sdn**2*born/pi*alphas*cf*(-1d0/4)
     & +ln1sdn*lnlas*born/pi*alphas*cf*(1d0/2)
     & +ln1sdn*log(4*omega**2/s)*born/pi*alphas*cf*(1d0/2)
     & +ln1sup**2*born/pi*alphas*cf*(-1d0/4)
     & +ln1sup*lnlas*born/pi*alphas*cf*(1d0/2)
     & +ln1sup*log(4*omega**2/s)*born/pi*alphas*cf*(1d0/2)
     & +ddilog(1d0)*born/pi*alphas*cf*(-2)

      soft = virt+soft

      return
      end
************************************************************************
* This is the FORTRAN module (cc_qcd_ha_1413_1211_1spr) to calculate hard
* gluon Bremsstrahlung for dn + up -> el + en process.
*
* It is produced by s2n package of SANC (v1.10) Project.
* Copyright (C), SANC Project Team, 2002-2008.
*
* http://sanc.jinr.ru/
* http://pcphsanc.cern.ch/
* E-mail: <sanc@jinr.ru>
************************************************************************
      subroutine cc_qcd_ha_1413_1211_1spr (s,spr,hard)
      implicit none!
      include 's2n_declare.h'

      real*8 kappaw
      real*8 ln1sdn,ln1sup
      complex*16 chiwspr,chiwsprc

      cmw2 = mw2

      kappaw = gf*rwm2/(sqrt(2d0)*4d0*pi)/alpha
      chiwspr = 4d0*kappaw*spr/(spr-cmw2)
      chiwsprc = dconjg(chiwspr)

      ln1sdn = log(s/mdn**2)-1d0
      ln1sup = log(s/mup**2)-1d0

      hard=
     & +ln1sdn*chiwspr*chiwsprc*alpha**2*alphas*cf*(-1d0/18/s**2+1d0/18/
     & s/spr+1d0/9/s/(s-spr))
     & +ln1sup*chiwspr*chiwsprc*alpha**2*alphas*cf*(-1d0/18/s**2+1d0/18/
     & s/spr+1d0/9/s/(s-spr))

      hard = hard*conhc

      return
      end
